@@ -417,7 +417,7 @@ class TwitterAds:
     '''
       Ref - https://dev.twitter.com/ads/reference/post/accounts/%3Aaccount_id/cards/website
     '''
-    def create_website_tweet_card(self, account_id, card_name, website_title, website_url, website_cta, img_path_list=[]):
+    def create_website_tweet_card(self, account_id, card_name, website_title, website_url, website_cta='', img_path_list=[]):
         
         assert account_id is not None, 'account_id is required'
         
@@ -431,8 +431,7 @@ class TwitterAds:
         params = {
                   'name' : card_name,
                   'website_title' : website_title,
-                  'website_url' : website_url,
-                  'website_cta' : website_cta
+                  'website_url' : website_url
                }
         if len(media_ids) > 0:
             params['image_media_id'] = ",".join(media_ids)
